@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use DateTime;
 use DateTime::Format::Strptime;
@@ -38,7 +38,7 @@ sub _build_full_data {
     my $self = shift;
 
     my $uri = $self->client->base_uri;
-    return $self->client->response_for( uri => $uri . $self->href );
+    return $self->client->decoded_json_for( uri => $uri . $self->href );
 }
 
 my $parser = DateTime::Format::Strptime->new( pattern => '%Y%m%dT%H%M%S%z' );
@@ -61,7 +61,7 @@ WebService::TeamCity::Entity - Role for anything addressable via the TeamCity RE
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
