@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use WebService::TeamCity::Iterator;
 
@@ -42,7 +42,7 @@ sub _iterator_for {
     my $items_key = shift;
     my $class     = shift;
 
-    my $raw = $self->client->response_for( uri => $uri );
+    my $raw = $self->client->decoded_json_for( uri => $uri );
 
     my %args = (
         client    => $self->client,
@@ -75,7 +75,7 @@ WebService::TeamCity::Inflator - Role for any class that inflates REST API objec
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
