@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Types::Standard qw( ArrayRef HashRef InstanceOf Int Str );
 
@@ -76,7 +76,7 @@ sub _fetch_more {
 
     return 0 unless $self->_has_next_href;
 
-    my $raw = $self->client->response_for(
+    my $raw = $self->client->decoded_json_for(
         uri => $self->client->base_uri . $self->_next_href );
 
     push @{ $self->_items }, @{ $raw->{ $self->items_key } };
@@ -105,7 +105,7 @@ WebService::TeamCity::Iterator - Generic object iterator for paged results from
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
